@@ -15,14 +15,14 @@ class WinkBinarySwitch(WinkDevice):
         :return: nothing
         """
         values = {"desired_state": {"powered": state}}
-        response = self.api_interface.set_device_state(self, values, type_override="binary_switche")
+        response = self.api_interface.local_set_state(self, values, type_override="binary_switche")
         self._update_state_from_response(response)
 
     def update_state(self):
         """
         Update state with latest info from Wink API.
         """
-        response = self.api_interface.get_device_state(self, type_override="binary_switche")
+        response = self.api_interface.local_get_state(self, type_override="binary_switche")
         return self._update_state_from_response(response)
 
 
@@ -40,8 +40,13 @@ class WinkLeakSmartValve(WinkBinarySwitch):
         :return: nothing
         """
         values = {"desired_state": {"opened": state}}
-        response = self.api_interface.set_device_state(self, values, type_override="binary_switche")
+        response = self.api_interface.local_set_state(self, values, type_override="binary_switche")
         self._update_state_from_response(response)
 
     def last_event(self):
         return self._last_reading.get("last_event")
+
+    def update_state(self):
+        """ Update state with latest info from Wink API. """
+        response = self.api_interface.local_get_state(self)
+        return self._update_state_from_response(response)
