@@ -10,7 +10,7 @@ class WinkKey(WinkDevice):
         super(WinkKey, self).__init__(device_state_as_json, api_interface)
         self._available = True
         self._unit = None
-        self._cap = "activity_detected"
+        self._capability = "activity_detected"
 
     def state(self):
         return self._last_reading.get(self.capability(), False)
@@ -29,4 +29,4 @@ class WinkKey(WinkDevice):
         return self._unit
 
     def capability(self):
-        return self._cap
+        return self._capability
